@@ -26,7 +26,7 @@ int q_dump = 0;
 #include "op.h"
 
 
-static int debug = 0;
+int debug = 0;
 
 
 void PREFIX(report)(int severity,const char *msg,...)
